DurableObjectListOptions class

Available extensions
Annotations
  • @anonymous
  • @JS.new()
  • @staticInterop

Constructors

DurableObjectListOptions()
factory

Properties

allowConcurrency ← bool?

Available on DurableObjectListOptions, provided by the PropsDurableObjectListOptions extension

no getter
end ← String?

Available on DurableObjectListOptions, provided by the PropsDurableObjectListOptions extension

no getter
hashCode → int
The hash code for this object.
no setterinherited
limit ← bool?

Available on DurableObjectListOptions, provided by the PropsDurableObjectListOptions extension

no getter
noCache ← bool?

Available on DurableObjectListOptions, provided by the PropsDurableObjectListOptions extension

no getter
prefix ← String?

Available on DurableObjectListOptions, provided by the PropsDurableObjectListOptions extension

no getter
reverse ← bool?

Available on DurableObjectListOptions, provided by the PropsDurableObjectListOptions extension

no getter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
start ← String?

Available on DurableObjectListOptions, provided by the PropsDurableObjectListOptions extension

no getter
startAfter ← String?

Available on DurableObjectListOptions, provided by the PropsDurableObjectListOptions extension

no getter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited