DurableObjectStorage class

Implementers
Available extensions
Annotations
  • @anonymous
  • @JS.new()
  • @staticInterop

Constructors

DurableObjectStorage()
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

delete<T>(String key, DurableObjectPutOptions options) → Future<bool>

Available on DurableObjectStorage, provided by the PropsDurableObjectStorage extension

deleteAlarm([DurableObjectSetAlarmOptions? options]) → Future<void>

Available on DurableObjectStorage, provided by the PropsDurableObjectStorage extension

deleteAll(DurableObjectPutOptions options) → Future<void>

Available on DurableObjectStorage, provided by the PropsDurableObjectStorage extension

deleteEntries<T>(Iterable<String> keys, [DurableObjectPutOptions? options]) → Future<bool>

Available on DurableObjectStorage, provided by the PropsDurableObjectStorage extension

get(dynamic keys, DurableObjectGetOptions options) → Future

Available on DurableObjectStorage, provided by the PropsDurableObjectStorage extension

getAlarm([DurableObjectGetAlarmOptions? options]) → Future<int?>

Available on DurableObjectStorage, provided by the PropsDurableObjectStorage extension

list<T>([DurableObjectListOptions? options]) → Future<Map<Object, T>>

Available on DurableObjectStorage, provided by the PropsDurableObjectStorage extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
put(String key, dynamic value, DurableObjectPutOptions options) → Future

Available on DurableObjectStorage, provided by the PropsDurableObjectStorage extension

putEntries<T>(Map<Object, T> entries, DurableObjectPutOptions options) → Future<void>

Available on DurableObjectStorage, provided by the PropsDurableObjectStorage extension

setAlarm(DateTime scheduled, [DurableObjectSetAlarmOptions? options]) → Future<void>

Available on DurableObjectStorage, provided by the PropsDurableObjectStorage extension

sync() → Future<void>

Available on DurableObjectStorage, provided by the PropsDurableObjectStorage extension

toString() → String
A string representation of this object.
inherited
transaction(Future<void> callback(DurableObjectTransaction tsx)) → Future<void>

Available on DurableObjectStorage, provided by the PropsDurableObjectStorage extension

Operators

operator ==(Object other) → bool
The equality operator.
inherited