Comment class

Available extensions
Annotations
  • @anonymous
  • @JS.new()
  • @staticInterop

Constructors

Comment()
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
removed → bool

Available on Comment, provided by the PropsComment extension

no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
text ↔ String

Available on Comment, provided by the PropsComment extension

getter/setter pair

Methods

after(String text, [ContentOptions? options]) → Comment

Available on Comment, provided by the PropsComment extension

before(String text, [ContentOptions? options]) → Comment

Available on Comment, provided by the PropsComment extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
remove() → Comment

Available on Comment, provided by the PropsComment extension

replace(String text, [ContentOptions? options]) → Comment

Available on Comment, provided by the PropsComment extension

toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited