Element class

Available extensions
Annotations
  • @anonymous
  • @JS.new()
  • @staticInterop

Constructors

Element()
factory

Properties

attributes → Iterable<String>

Available on Element, provided by the PropsElement extension

no setter
hashCode → int
The hash code for this object.
no setterinherited
namespaceURI → String

Available on Element, provided by the PropsElement extension

no setter
removed → bool

Available on Element, provided by the PropsElement extension

no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tagName ↔ String

Available on Element, provided by the PropsElement extension

getter/setter pair

Methods

after(String text, [ContentOptions? options]) → Element

Available on Element, provided by the PropsElement extension

append(String text, [ContentOptions? options]) → Element

Available on Element, provided by the PropsElement extension

before(String text, [ContentOptions? options]) → Element

Available on Element, provided by the PropsElement extension

getAttribute(String name) → String?

Available on Element, provided by the PropsElement extension

hasAttribute(String name) → bool

Available on Element, provided by the PropsElement extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onEndTag(dynamic handler) → void

Available on Element, provided by the PropsElement extension

prepend(String text, [ContentOptions? options]) → Element

Available on Element, provided by the PropsElement extension

remove() → Element

Available on Element, provided by the PropsElement extension

removeAndKeepContent() → Element

Available on Element, provided by the PropsElement extension

removeAttribute(String name) → Element

Available on Element, provided by the PropsElement extension

replace(String text, [ContentOptions? options]) → Element

Available on Element, provided by the PropsElement extension

setAttribute(String name, String value) → Element

Available on Element, provided by the PropsElement extension

setInnerContent(String text, [ContentOptions? options]) → Element

Available on Element, provided by the PropsElement extension

toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited