HTMLRewriter class

Available extensions
Annotations
  • @JS.new()
  • @staticInterop

Constructors

HTMLRewriter()
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
on(String selector, ElementHandler handler) → HTMLRewriter

Available on HTMLRewriter, provided by the PropsHTMLRewriter extension

onDocument(DocumentHandler handler) → HTMLRewriter

Available on HTMLRewriter, provided by the PropsHTMLRewriter extension

toString() → String
A string representation of this object.
inherited
transform(Response response) → Response

Available on HTMLRewriter, provided by the PropsHTMLRewriter extension

Operators

operator ==(Object other) → bool
The equality operator.
inherited