Text class

Available extensions
Annotations
  • @anonymous
  • @JS.new()
  • @staticInterop

Constructors

Text()
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
lastInTextNode → bool

Available on Text, provided by the PropsText extension

no setter
removed → bool

Available on Text, provided by the PropsText extension

no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
text → String

Available on Text, provided by the PropsText extension

no setter

Methods

after(String text, [ContentOptions? options]) → Text

Available on Text, provided by the PropsText extension

before(String text, [ContentOptions? options]) → Text

Available on Text, provided by the PropsText extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
remove() → Text

Available on Text, provided by the PropsText extension

replace(String text, [ContentOptions? options]) → Text

Available on Text, provided by the PropsText extension

toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited