KVNamespacePutOptions class

Available extensions
Annotations
  • @anonymous
  • @JS.new()
  • @staticInterop

Constructors

KVNamespacePutOptions()
factory

Properties

expiration ← DateTime?

Available on KVNamespacePutOptions, provided by the PropsKVNamespacePutOptions extension

no getter
expirationTtl ← int?

Available on KVNamespacePutOptions, provided by the PropsKVNamespacePutOptions extension

no getter
hashCode → int
The hash code for this object.
no setterinherited
metadata ← Object?

Available on KVNamespacePutOptions, provided by the PropsKVNamespacePutOptions extension

no getter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited