IncomingRequestCfProperties class

Annotations
  • @JS.new()
  • @anonymous

Properties

asn → int
(e.g. 395747)
no setter
asOrganization → String
The organization which owns the ASN of the incoming request. (e.g. Google Cloud)
no setter
botManagement → IncomingRequestCfPropertiesBotManagement?
no setter
city → String?
no setter
clientAcceptEncoding → String?
no setter
clientTcpRtt → num
no setter
clientTrustScore → num
no setter
colo → String
The three-letter airport code of the data center that the request hit. (e.g. "DFW")
no setter
continent → String?
no setter
country → String
The two-letter country code in the request. This is the same value as that provided in the CF-IPCountry header. (e.g. "US")
no setter
hashCode → int
The hash code for this object.
no setterinherited
httpProtocol → String
no setter
latitude → String?
no setter
longitude → String?
no setter
metroCode → String?
DMA metro code from which the request was issued, e.g. "635"
no setter
postalCode → String?
no setter
region → String?
e.g. "Texas"
no setter
regionCode → String?
e.g. "TX"
no setter
requestPriority → String
e.g. "weight=256;exclusive=1"
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timezone → String?
e.g. "America/Chicago"
no setter
tlsCipher → String
no setter
tlsClientAuth → IncomingRequestCfPropertiesTLSClientAuth
no setter
tlsVersion → String
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited