DurableObjectId class

Available extensions

Properties

delegate → DurableObjectId

Available on DurableObjectId, provided by the DurableObjectIdExtension extension

no setter
hashCode → int
The hash code for this object.
no setterinherited
name → String
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

equals(DurableObjectId other) → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited