DurableObjectState class

Properties

hashCode → int
The hash code for this object.
no setterinherited
id → DurableObjectId
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
storage → DurableObjectStorage
no setter

Methods

blockConcurrencyWhile<T>(Future<T> callback()) → Future<T>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
waitUntil(Future<void> future) → void

Operators

operator ==(Object other) → bool
The equality operator.
inherited