DurableObjectStorage class

Implementers
Available extensions

Properties

delegate → DurableObjectStorage

Available on DurableObjectStorage, provided by the DurableObjectStorageExtension extension

no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

delete(String key, {bool? allowConcurrency, bool? allowUnconfirmed, bool? noCache}) → Future<bool>
deleteAlarm({bool? allowConcurrency, bool? allowUnconfirmed}) → Future<void>
deleteAll({bool? allowConcurrency, bool? allowUnconfirmed, bool? noCache}) → Future<void>
deleteEntries(Iterable<String> keys, {bool? allowConcurrency, bool? allowUnconfirmed, bool? noCache}) → Future<bool>
get<T>(String key, {bool? allowConcurrency, bool? noCache}) → Future<T?>
getAlarm({bool? allowConcurrency}) → Future<int?>
getEntries<T>(Iterable<String> keys, {bool? allowConcurrency, bool? noCache}) → Future<Map<String, T>>
list<T>({String? start, String? startAfter, String? end, String? prefix, bool? reverse, bool? limit, bool? allowConcurrency, bool? noCache}) → Future<Map<String, T>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
put<T>(String key, T value, {bool? allowConcurrency, bool? allowUnconfirmed, bool? noCache}) → Future<void>
putEntries<T>(Map<Object, T> entries, {bool? allowConcurrency, bool? allowUnconfirmed, bool? noCache}) → Future<void>
setAlarm(DateTime scheduledTime, {bool? allowConcurrency, bool? allowUnconfirmed}) → Future<void>
sync() → Future<void>
toString() → String
A string representation of this object.
inherited
transaction(Future<void> callback(DurableObjectTransaction tsx)) → Future<void>

Operators

operator ==(Object other) → bool
The equality operator.
inherited