Comment class

Properties

hashCode → int
The hash code for this object.
no setterinherited
removed → bool
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
text ↔ String
getter/setter pair

Methods

after(String text, [ContentOptions? options]) → Comment
before(String text, [ContentOptions? options]) → Comment
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
remove() → Comment
replace(String text, [ContentOptions? options]) → Comment
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited