HTMLRewriter class

Available extensions

Constructors

HTMLRewriter()

Properties

delegate → HTMLRewriter

Available on HTMLRewriter, provided by the HTMLRewriterExtension extension

no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
on(String selector, ElementHandler handler) → HTMLRewriter
onDocument(DocumentHandler handler) → HTMLRewriter
toString() → String
A string representation of this object.
inherited
transform(Response response) → Response

Operators

operator ==(Object other) → bool
The equality operator.
inherited