Text class

Properties

hashCode → int
The hash code for this object.
no setterinherited
lastInTextNode → bool
no setter
removed → bool
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
text → String
no setter

Methods

after(String text, [ContentOptions? options]) → Text
before(String text, [ContentOptions? options]) → Text
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
remove() → Text
replace(String text, [ContentOptions? options]) → Text
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited