IncomingRequestCfPropertiesTLSClientAuth class

Properties

certFingerprintSHA1 → String
no setter
certIssuerDN → String
no setter
certIssuerDNLegacy → String
no setter
certNotAfter → String
In format "Dec 22 19:39:00 2018 GMT"
no setter
certNotBefore → String
In format "Dec 22 19:39:00 2018 GMT"
no setter
certPresented → String
no setter
certSerial → String
no setter
certSubjectDN → String
no setter
certSubjectDNLegacy → String
no setter
certVerified → String
"SUCCESS", "FAILED:reason", "NONE"
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited