BasicImageTransformations class

Implementers

Constructors

BasicImageTransformations({num? width, num? height, BasicImageTransformationsFit? fit, BasicImageTransformationsGravity? gravity, String? background, int? rotate})

Properties

background ↔ String?
getter/setter pair
fit ↔ BasicImageTransformationsFit?
getter/setter pair
gravity ↔ BasicImageTransformationsGravity?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
height ↔ num?
getter/setter pair
rotate ↔ int?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
width ↔ num?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited