CloudflareRequestInitImageMinify class

Available extensions

Constructors

CloudflareRequestInitImageMinify({bool? javascript, bool? css, bool? html})

Properties

css ↔ bool?
getter/setter pair
delegate → RequestInitCfPropertiesImageMinify

Available on CloudflareRequestInitImageMinify, provided by the CloudflareRequestInitImageMinifyExtension extension

no setter
hashCode → int
The hash code for this object.
no setterinherited
html ↔ bool?
getter/setter pair
javascript ↔ bool?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited